﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Diagnostics;
using HeuristicLab.Clients.Hive.SlaveCore.ServiceContracts;

namespace HeuristicLab.Clients.Hive.SlaveCore {

  /// <summary>
  /// Class for writing the client communication to Trace
  /// </summary>
  public class TraceCom : IClientCom {
    private ISlaveCommunication clientCom;

    public TraceCom() {
      clientCom = new TraceSlaveCommunication();
    }

    public ISlaveCommunication GetSlaveCom() {
      return clientCom;
    }

    public void Close() {
      // Nothing to do here ...
    }

    #region Private Class
    private class TraceSlaveCommunication : ISlaveCommunication {

      public TraceSlaveCommunication() {

      }

      public StatusCommons Subscribe() {
        Trace.WriteLine("Subscribe");
        return new StatusCommons();
      }

      public bool Unsubscribe() {
        Trace.WriteLine("Unsubscribe");
        return false;
      }

      public void Restart() {
        Trace.WriteLine("Restart");
      }

      public void Sleep() {
        Trace.WriteLine("Sleep");
      }

      public void PauseAll() {
        Trace.WriteLine("PauseAll");
      }

      public void StopAll() {
        Trace.WriteLine("StopAll");
      }

      public void AbortAll() {
        Trace.WriteLine("AbortAll");
      }

      public void LogMessage(string message) {
        Trace.WriteLine(message);
      }

      public void StatusChanged(StatusCommons status) {
        Trace.WriteLine("StatusChanged: " + status);
      }

      public void Shutdown() {
        Trace.WriteLine("Shutdown");
      }
    }

    #endregion
  }
}